aboutsummaryrefslogtreecommitdiff
path: root/bindings/java/src/java/com/galois/ppaml/tracer/Phase.java
diff options
context:
space:
mode:
Diffstat (limited to 'bindings/java/src/java/com/galois/ppaml/tracer/Phase.java')
-rw-r--r--bindings/java/src/java/com/galois/ppaml/tracer/Phase.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/bindings/java/src/java/com/galois/ppaml/tracer/Phase.java b/bindings/java/src/java/com/galois/ppaml/tracer/Phase.java
index 23ed2f4..019704f 100644
--- a/bindings/java/src/java/com/galois/ppaml/tracer/Phase.java
+++ b/bindings/java/src/java/com/galois/ppaml/tracer/Phase.java
@@ -27,9 +27,9 @@ package com.galois.ppaml.tracer;
public final class Phase extends CWrapper {
/**
* The <code>Tracer</code> this phase is associated with.
*/
- private final Tracer tracer;
+ private final TracerCWrapper tracer;
/**
* The name of the phase.
@@ -38,14 +38,14 @@ public final class Phase extends CWrapper {
/**
* Creates and initializes a <code>Phase</code>. You should not call this;
- * call {@link Tracer.createPhase} instead.
+ * call <code>Tracer.createPhase</code> instead.
*
* @param tracer the {@link Tracer} to associate the <code>Phase</code>
* with.
*
* @param name the name of the phase.
*/
- protected Phase(Tracer tracer, final String name) {
+ protected Phase(TracerCWrapper tracer, final String name) {
this.tracer = tracer;
this.name = name;
super.open();
@@ -27,9 +27,9 @@ package com.galois.ppaml.tracer;
public final class Phase extends CWrapper {
/**
- * The <code>Tracer</code> this phase is associated with.
+ * The <code>TracerCWrapper</code> this phase is associated with.
*/
@@ -38,14 +38,14 @@ public final class Phase extends CWrapper {
*
- * @param tracer the {@link Tracer} to associate the <code>Phase</code>
- * with.
+ * @param tracer the {@link TracerCWrapper} to associate the
+ * <code>Phase</code> with.
*
* @param name the name of the phase.